==> mfc-es-api-1.3.4-sources.jar: com/mfc/es/api/model/service/media/MediaUserReview.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractLocaleDoc;
import org.elasticsearch.common.Strings;

import java.util.Date;

/**
 * Created by Frank.Huang on 2017/3/6.
 */
public class MediaUserReview extends AbstractLocaleDoc {
    private String reviewKey;
    private String source;
    private String userName;
    private String userLocation;
    private String reviewDate;
    private String summary;
    private String content;
    private Integer userScore;
    private Integer userScoreCount;
    private Integer userRating;
    private Date createTime;

    public String getReviewKey() {
        return reviewKey;
    }

    public void setReviewKey(String reviewKey) {
        this.reviewKey = reviewKey;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserLocation() {
        return userLocation;
    }

    public void setUserLocation(String userLocation) {
        this.userLocation = userLocation;
    }

    public String getReviewDate() {
        return reviewDate;
    }

    public void setReviewDate(String reviewDate) {
        this.reviewDate = reviewDate;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getUserScore() {
        return userScore;
    }

    public void setUserScore(Integer userScore) {
        this.userScore = userScore;
    }

    public Integer getUserScoreCount() {
        return userScoreCount;
    }

    public void setUserScoreCount(Integer userScoreCount) {
        this.userScoreCount = userScoreCount;
    }

    public Integer getUserRating() {
        return userRating;
    }

    public void setUserRating(Integer userRating) {
        this.userRating = userRating;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public String getDocumentId() {
        if (!Strings.isNullOrEmpty(documentId)) {
            return documentId;
        }
        return makeDocumentId(reviewKey, language, id);
    }
}

==> mfc-es-api-1.3.7-sources.jar: com/mfc/es/api/model/service/media/MediaUserReview.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractLocaleDoc;
import org.elasticsearch.common.Strings;

import java.util.Date;
import java.util.Objects;

/**
 * Created by Frank.Huang on 2017/3/6.
 */
public class MediaUserReview extends AbstractLocaleDoc {
    private String reviewKey;
    private String source;
    private String userName;
    private String userLocation;
    private String reviewDate;
    private String summary;
    private String content;
    private Integer userScore;
    private Integer userScoreCount;
    private Integer userRating;
    private Date createTime;

    public String getReviewKey() {
        return reviewKey;
    }

    public void setReviewKey(String reviewKey) {
        this.reviewKey = reviewKey;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserLocation() {
        return userLocation;
    }

    public void setUserLocation(String userLocation) {
        this.userLocation = userLocation;
    }

    public String getReviewDate() {
        return reviewDate;
    }

    public void setReviewDate(String reviewDate) {
        this.reviewDate = reviewDate;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getUserScore() {
        return userScore;
    }

    public void setUserScore(Integer userScore) {
        this.userScore = userScore;
    }

    public Integer getUserScoreCount() {
        return userScoreCount;
    }

    public void setUserScoreCount(Integer userScoreCount) {
        this.userScoreCount = userScoreCount;
    }

    public Integer getUserRating() {
        return userRating;
    }

    public void setUserRating(Integer userRating) {
        this.userRating = userRating;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public String getDocumentId() {
        if (!Strings.isNullOrEmpty(documentId)) {
            return documentId;
        }
        return makeDocumentId(reviewKey, language, id);
    }

//    public boolean valueEquals(Object o) {
//        if (o == null || getClass() != o.getClass()) return false;
//        MediaUserReview that = (MediaUserReview) o;
//        return Objects.equals(source, that.source) &&
//                Objects.equals(userName, that.userName) &&
//                Objects.equals(userLocation, that.userLocation) &&
//                Objects.equals(reviewDate, that.reviewDate) &&
//                Objects.equals(summary, that.summary) &&
//                Objects.equals(content, that.content) &&
//                Objects.equals(userScore, that.userScore) &&
//                Objects.equals(userScoreCount, that.userScoreCount) &&
//                Objects.equals(userRating, that.userRating);
//    }

}
